# Mizani

[![Release](https://img.shields.io/pypi/v/mizani.svg)](https://pypi.python.org/pypi/mizani)
[![License](https://img.shields.io/pypi/l/mizani.svg)](https://pypi.python.org/pypi/mizani)
[![Build Status](https://github.com/has2k1/mizani/workflows/build/badge.svg?branch=main)](https://github.com/has2k1/mizani/actions?query=branch%3Amain+workflow%3A%22build%22)
[![Documentation](https://readthedocs.org/projects/mizani/badge/?version=latest)](https://mizani.readthedocs.io/en/latest/)
[![Coverage](https://codecov.io/github/has2k1/mizani/coverage.svg?branch=main)](https://codecov.io/github/has2k1/mizani?branch=main)

Mizani is a scales package for graphics. It is written in Python and is
based on Hadley Wickham's [Scales](https://github.com/r-lib/scales).
See the [documentation](https://mizani.readthedocs.io/en/latest/)
for how to use it in a graphics system.

## Installation

Official Release

```console
$ pip install mizani
```

Development version

```console
$ pip install git+https://github.com/has2k1/mizani.git@main
```
